aboutsummaryrefslogtreecommitdiffstats
path: root/src/ports/FontHostConfiguration_android.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/ports/FontHostConfiguration_android.h')
-rw-r--r--src/ports/FontHostConfiguration_android.h17
1 files changed, 13 insertions, 4 deletions
diff --git a/src/ports/FontHostConfiguration_android.h b/src/ports/FontHostConfiguration_android.h
index 2441f0e..c8a70e3 100644
--- a/src/ports/FontHostConfiguration_android.h
+++ b/src/ports/FontHostConfiguration_android.h
@@ -18,18 +18,27 @@
#define FONTHOSTCONFIGURATION_ANDROID_H_
#include "SkTDArray.h"
+#include "SkPaint.h"
+
+struct FontFileInfo {
+ FontFileInfo() : fVariant(SkPaint::kDefault_Variant), fLanguage(NULL), fFileName(NULL) {}
+ const char* fFileName;
+ SkPaint::FontVariant fVariant;
+ const char* fLanguage; // We may eventually use a enum for this
+};
+
/**
* The FontFamily data structure is created during parsing and handed back to
* Skia to fold into its representation of font families. fNames is the list of
* font names that alias to a font family. fFileNames is the list of font
* filenames for the family. Order is the priority order for the font. This is
* used internally to determine the order in which to place fallback fonts as
* they are read from the configuration files.
*/
struct FontFamily {
- SkTDArray<const char*> fNames;
- SkTDArray<const char*> fFileNames;
+ SkTDArray<const char*> fNames;
+ SkTDArray<FontFileInfo*> fFontFileArray;
int order;
};
@@ -18,18 +18,27 @@
* The FontFamily data structure is created during parsing and handed back to
* Skia to fold into its representation of font families. fNames is the list of
- * font names that alias to a font family. fFileNames is the list of font
- * filenames for the family. Order is the priority order for the font. This is
+ * font names that alias to a font family. fontFileArray is the list of information
+ * about each file. Order is the priority order for the font. This is
* used internally to determine the order in which to place fallback fonts as
* they are read from the configuration files.